@@ -306,7 +306,8 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         case_results = validator.run()
         write_test_results(case_results, '.biosimulators-test-suite-results.json',
                            gh_issue=int(self.issue_number), gh_action_run=int(self.get_gh_action_run_id()))
-        summary, failure_details, warning_details, skipped_details = validator.summarize_results(case_results)
+        summary, failure_details, warning_details, skipped_details = validator.summarize_results(
+            case_results, output_medium=OutputMedium.gh_issue)
 
         # print summary to console
         print('')
@@ -344,15 +345,15 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         self.add_comment_to_issue(self.issue_number, msg, alternative_comment=unable_to_post_results_msg)
 
         if failure_details:
-            msg = '\n## Failures\n\n{}\n\n'.format('### ' + '\n### '.join(failure_details))
+            msg = '\n## Failures\n\n{}\n\n'.format('\n\n'.join(failure_details))
             self.add_comment_to_issue(self.issue_number, msg, alternative_comment=unable_to_post_results_msg)
 
         if warning_details:
-            msg = '\n## Warnings\n\n{}\n\n'.format('### ' + '\n### '.join(warning_details))
+            msg = '\n## Warnings\n\n{}\n\n'.format('\n\n'.join(warning_details))
             self.add_comment_to_issue(self.issue_number, msg, alternative_comment=unable_to_post_results_msg)
 
         if skipped_details:
-            msg = '\n## Skips\n\n{}\n\n'.format('### ' + '\n### '.join(skipped_details))
+            msg = '\n## Skips\n\n{}\n\n'.format('\n\n'.join(skipped_details))
             self.add_comment_to_issue(self.issue_number, msg, alternative_comment=unable_to_post_results_msg)
 
         invalid_cases = [case_result for case_result in case_results if case_result.type == TestCaseResultType.failed]
@@ -430,9 +431,6 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
             # copy image to BioSimulators namespace of Docker registry (GitHub Container Registry)
             self.push_image(specifications, existing_version_specifications)
 
-            # instruct runBioSimulations to generate a Singularity image for the Docker image
-            self.trigger_conversion_of_docker_image_to_singularity(specifications)
-
         # commit submission to BioSimulators database
         if 'biosimulators' not in specifications:
             specifications['biosimulators'] = {}
@@ -449,6 +447,11 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
 
         self.post_entry_to_biosimulators_api(specifications, existing_version_specifications)
 
+        # commit image
+        if submission.validate_image:
+            # instruct runBioSimulations to generate a Singularity image for the Docker image
+            self.trigger_conversion_of_docker_image_to_singularity(specifications)
+
     def push_image(self, specifications, existing_version_specifications):
         """ Push the image for a simulation tool to the GitHub Container Registry
 
@@ -474,6 +477,9 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         biosimulators_utils.image.tag_and_push_docker_image(docker_client, image, copy_image_url)
         specifications['image']['url'] = copy_image_url
 
+        image = get_docker_image(docker_client, copy_image_url, pull=False)
+        specifications['image']['digest'] = image.attrs['RepoDigests'][0].partition('@')[2]
+
         is_latest = self.is_submission_latest_version_of_simulator(specifications, existing_version_specifications)
 
         if is_latest:
